@@ -1,22 +1,10 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2000-2005 David Faure <faure@kde.org>
-   Copyright (C) 2003 Leo Savernik <l.savernik@aon.at>
+   SPDX-FileCopyrightText: 2000-2005 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2003 Leo Savernik <l.savernik@aon.at>
 
    Moved from ktar.cpp by Roberto Teixeira <maragato@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only
 */
 
 #include "karchive.h"
@@ -26,36 +14,100 @@
 
 #include <qplatformdefs.h> // QT_STATBUF, QT_LSTAT
 
-#include <QStack>
-#include <QMap>
 #include <QDebug>
 #include <QDir>
 #include <QFile>
+#include <QMap>
+#include <QStack>
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
 
 #include <assert.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
 #ifdef Q_OS_UNIX
 #include <grp.h>
+#include <limits.h> // PATH_MAX
 #include <pwd.h>
-#include <limits.h>  // PATH_MAX
 #include <unistd.h>
 #endif
 #ifdef Q_OS_WIN
 #include <windows.h> // DWORD, GetUserNameW
 #endif // Q_OS_WIN
 
+////////////////////////////////////////////////////////////////////////
+/////////////////// KArchiveDirectoryPrivate ///////////////////////////
+////////////////////////////////////////////////////////////////////////
+
+class KArchiveDirectoryPrivate
+{
+public:
+    KArchiveDirectoryPrivate(KArchiveDirectory *parent)
+        : q(parent)
+    {
+    }
+
+    ~KArchiveDirectoryPrivate()
+    {
+        qDeleteAll(entries);
+    }
+
+    KArchiveDirectoryPrivate(const KArchiveDirectoryPrivate &) = delete;
+    KArchiveDirectoryPrivate &operator=(const KArchiveDirectoryPrivate &) = delete;
+
+    static KArchiveDirectoryPrivate *get(KArchiveDirectory *directory)
+    {
+        return directory->d;
+    }
+
+    // Returns in containingDirectory the directory that actually contains the returned entry
+    const KArchiveEntry *entry(const QString &_name, KArchiveDirectory **containingDirectory) const
+    {
+        *containingDirectory = q;
+
+        QString name = QDir::cleanPath(_name);
+        int pos = name.indexOf(QLatin1Char('/'));
+        if (pos == 0) { // ouch absolute path (see also KArchive::findOrCreate)
+            if (name.length() > 1) {
+                name = name.mid(1); // remove leading slash
+                pos = name.indexOf(QLatin1Char('/')); // look again
+            } else { // "/"
+                return q;
+            }
+        }
+        // trailing slash ? -> remove
+        if (pos != -1 && pos == name.length() - 1) {
+            name = name.left(pos);
+            pos = name.indexOf(QLatin1Char('/')); // look again
+        }
+        if (pos != -1) {
+            const QString left = name.left(pos);
+            const QString right = name.mid(pos + 1);
+
+            // qCDebug(KArchiveLog) << "left=" << left << "right=" << right;
+
+            KArchiveEntry *e = entries.value(left);
+            if (!e || !e->isDirectory()) {
+                return nullptr;
+            }
+            *containingDirectory = static_cast<KArchiveDirectory *>(e);
+            return (*containingDirectory)->d->entry(right, containingDirectory);
+        }
+
+        return entries.value(name);
+    }
+
+    KArchiveDirectory *q;
+    QHash<QString, KArchiveEntry *> entries;
+};
+
 ////////////////////////////////////////////////////////////////////////
 /////////////////////////// KArchive ///////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
 
 KArchive::KArchive(const QString &fileName)
-    : d(new KArchivePrivate)
+    : d(new KArchivePrivate(this))
 {
     if (fileName.isEmpty()) {
         qCWarning(KArchiveLog) << "KArchive: No file name specified";
@@ -66,7 +118,7 @@ KArchive::KArchive(const QString &fileName)
 }
 
 KArchive::KArchive(QIODevice *dev)
-    : d(new KArchivePrivate)
+    : d(new KArchivePrivate(this))
 {
     if (!dev) {
         qCWarning(KArchiveLog) << "KArchive: Null device specified";
@@ -119,12 +171,16 @@ bool KArchive::createDevice(QIODevice::OpenMode mode)
     case QIODevice::WriteOnly:
         if (!d->fileName.isEmpty()) {
             // The use of QSaveFile can't be done in the ctor (no mode known yet)
-            //qCDebug(KArchiveLog) << "Writing to a file using QSaveFile";
+            // qCDebug(KArchiveLog) << "Writing to a file using QSaveFile";
             d->saveFile = new QSaveFile(d->fileName);
+#ifdef Q_OS_ANDROID
+            // we cannot rename on to Android content: URLs
+            if (d->fileName.startsWith(QLatin1String("content://"))) {
+                d->saveFile->setDirectWriteFallback(true);
+            }
+#endif
             if (!d->saveFile->open(QIODevice::WriteOnly)) {
-                setErrorString(
-                    tr("QSaveFile creation for %1 failed: %2")
-                        .arg(d->fileName, d->saveFile->errorString()));
+                setErrorString(tr("QSaveFile creation for %1 failed: %2").arg(d->fileName, d->saveFile->errorString()));
 
                 delete d->saveFile;
                 d->saveFile = nullptr;
@@ -153,7 +209,7 @@ bool KArchive::close()
 {
     if (!isOpen()) {
         setErrorString(tr("Archive already closed"));
-        return false;    // already closed (return false or true? arguable...)
+        return false; // already closed (return false or true? arguable...)
     }
 
     // moved by holger to allow kzip to write the zip central dir
@@ -203,9 +259,7 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
 {
     QFileInfo fileInfo(fileName);
     if (!fileInfo.isFile() && !fileInfo.isSymLink()) {
-        setErrorString(
-            tr("%1 doesn't exist or is not a regular file.")
-            .arg(fileName));
+        setErrorString(tr("%1 doesn't exist or is not a regular file.").arg(fileName));
         return false;
     }
 
@@ -216,16 +270,13 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
 #endif
     QT_STATBUF fi;
     if (STAT_METHOD(QFile::encodeName(fileName).constData(), &fi) == -1) {
-        setErrorString(
-            tr("Failed accessing the file %1 for adding to the archive. The error was: %2")
-            .arg(fileName)
-            .arg(QLatin1Literal{strerror(errno)}));
+        setErrorString(tr("Failed accessing the file %1 for adding to the archive. The error was: %2").arg(fileName).arg(QLatin1String{strerror(errno)}));
         return false;
     }
 
     if (fileInfo.isSymLink()) {
         QString symLinkTarget;
-        // Do NOT use fileInfo.readLink() for unix symlinks!
+        // Do NOT use fileInfo.symLinkTarget() for unix symlinks!
         // It returns the -full- path to the target, while we want the target string "as is".
 #if defined(Q_OS_UNIX) && !defined(Q_OS_OS2EMX)
         const QByteArray encodedFileName = QFile::encodeName(fileName);
@@ -248,10 +299,15 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
         if (symLinkTarget.isEmpty()) { // Mac or Windows
             symLinkTarget = fileInfo.symLinkTarget();
         }
-        return writeSymLink(destName, symLinkTarget, fileInfo.owner(),
-                            fileInfo.group(), fi.st_mode, fileInfo.lastRead(), fileInfo.lastModified(),
-                            fileInfo.created());
-    }/*end if*/
+        return writeSymLink(destName,
+                            symLinkTarget,
+                            fileInfo.owner(),
+                            fileInfo.group(),
+                            fi.st_mode,
+                            fileInfo.lastRead(),
+                            fileInfo.lastModified(),
+                            fileInfo.birthTime());
+    } /*end if*/
 
     qint64 size = fileInfo.size();
 
@@ -260,15 +316,12 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
     // header and the tar file is effectively f*cked up
     QFile file(fileName);
     if (!file.open(QIODevice::ReadOnly)) {
-        setErrorString(
-            tr("Couldn't open file %1: %2")
-            .arg(fileName, file.errorString()));
+        setErrorString(tr("Couldn't open file %1: %2").arg(fileName, file.errorString()));
         return false;
     }
 
-    if (!prepareWriting(destName, fileInfo.owner(), fileInfo.group(), size,
-                        fi.st_mode, fileInfo.lastRead(), fileInfo.lastModified(), fileInfo.created())) {
-        //qCWarning(KArchiveLog) << " prepareWriting" << destName << "failed";
+    if (!prepareWriting(destName, fileInfo.owner(), fileInfo.group(), size, fi.st_mode, fileInfo.lastRead(), fileInfo.lastModified(), fileInfo.birthTime())) {
+        // qCWarning(KArchiveLog) << " prepareWriting" << destName << "failed";
         return false;
     }
 
@@ -279,7 +332,7 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
     qint64 total = 0;
     while ((n = file.read(array.data(), array.size())) > 0) {
         if (!writeData(array.data(), n)) {
-            //qCWarning(KArchiveLog) << "writeData failed";
+            // qCWarning(KArchiveLog) << "writeData failed";
             return false;
         }
         total += n;
@@ -287,7 +340,7 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
     Q_ASSERT(total == size);
 
     if (!finishWriting(size)) {
-        //qCWarning(KArchiveLog) << "finishWriting failed";
+        // qCWarning(KArchiveLog) << "finishWriting failed";
         return false;
     }
     return true;
@@ -297,9 +350,7 @@ bool KArchive::addLocalDirectory(const QString &path, const QString &destName)
 {
     QDir dir(path);
     if (!dir.exists()) {
-        setErrorString(
-            tr("Directory %1 does not exist")
-            .arg(path));
+        setErrorString(tr("Directory %1 does not exist").arg(path));
         return false;
     }
     dir.setFilter(dir.filter() | QDir::Hidden);
@@ -307,7 +358,7 @@ bool KArchive::addLocalDirectory(const QString &path, const QString &destName)
     for (QStringList::ConstIterator it = files.begin(); it != files.end(); ++it) {
         if (*it != QLatin1String(".") && *it != QLatin1String("..")) {
             QString fileName = path + QLatin1Char('/') + *it;
-//            qCDebug(KArchiveLog) << "storing " << fileName;
+            //            qCDebug(KArchiveLog) << "storing " << fileName;
             QString dest = destName.isEmpty() ? *it : (destName + QLatin1Char('/') + *it);
             QFileInfo fileInfo(fileName);
 
@@ -322,26 +373,30 @@ bool KArchive::addLocalDirectory(const QString &path, const QString &destName)
     return true;
 }
 
-bool KArchive::writeFile(const QString &name, const QByteArray &data,
+bool KArchive::writeFile(const QString &name,
+                         const QByteArray &data,
                          mode_t perm,
-                         const QString &user, const QString &group, const QDateTime &atime,
-                         const QDateTime &mtime, const QDateTime &ctime)
+                         const QString &user,
+                         const QString &group,
+                         const QDateTime &atime,
+                         const QDateTime &mtime,
+                         const QDateTime &ctime)
 {
     const qint64 size = data.size();
     if (!prepareWriting(name, user, group, size, perm, atime, mtime, ctime)) {
-        //qCWarning(KArchiveLog) << "prepareWriting failed";
+        // qCWarning(KArchiveLog) << "prepareWriting failed";
         return false;
     }
 
     // Write data
     // Note: if data is null, don't call write, it would terminate the KCompressionDevice
     if (data.constData() && size && !writeData(data.constData(), size)) {
-        //qCWarning(KArchiveLog) << "writeData failed";
+        // qCWarning(KArchiveLog) << "writeData failed";
         return false;
     }
 
     if (!finishWriting(size)) {
-        //qCWarning(KArchiveLog) << "finishWriting failed";
+        // qCWarning(KArchiveLog) << "finishWriting failed";
         return false;
     }
     return true;
@@ -351,9 +406,7 @@ bool KArchive::writeData(const char *data, qint64 size)
 {
     bool ok = device()->write(data, size) == size;
     if (!ok) {
-        setErrorString(
-            tr("Writing failed: %1")
-            .arg(device()->errorString()));
+        setErrorString(tr("Writing failed: %1").arg(device()->errorString()));
         d->abortWriting();
     }
     return ok;
@@ -365,25 +418,37 @@ bool KArchive::writeData(const char *data, qint64 size)
 // additional argument in the d pointer, and doWriteDir reimplementations can fetch
 // it from there.
 
-bool KArchive::writeDir(const QString &name, const QString &user, const QString &group,
-                        mode_t perm, const QDateTime &atime,
-                        const QDateTime &mtime, const QDateTime &ctime)
+bool KArchive::writeDir(const QString &name,
+                        const QString &user,
+                        const QString &group,
+                        mode_t perm,
+                        const QDateTime &atime,
+                        const QDateTime &mtime,
+                        const QDateTime &ctime)
 {
     return doWriteDir(name, user, group, perm | 040000, atime, mtime, ctime);
 }
 
-bool KArchive::writeSymLink(const QString &name, const QString &target,
-                            const QString &user, const QString &group,
-                            mode_t perm, const QDateTime &atime,
-                            const QDateTime &mtime, const QDateTime &ctime)
+bool KArchive::writeSymLink(const QString &name,
+                            const QString &target,
+                            const QString &user,
+                            const QString &group,
+                            mode_t perm,
+                            const QDateTime &atime,
+                            const QDateTime &mtime,
+                            const QDateTime &ctime)
 {
     return doWriteSymLink(name, target, user, group, perm, atime, mtime, ctime);
 }
 
-bool KArchive::prepareWriting(const QString &name, const QString &user,
-                              const QString &group, qint64 size,
-                              mode_t perm, const QDateTime &atime,
-                              const QDateTime &mtime, const QDateTime &ctime)
+bool KArchive::prepareWriting(const QString &name,
+                              const QString &user,
+                              const QString &group,
+                              qint64 size,
+                              mode_t perm,
+                              const QDateTime &atime,
+                              const QDateTime &mtime,
+                              const QDateTime &ctime)
 {
     bool ok = doPrepareWriting(name, user, group, size, perm, atime, mtime, ctime);
     if (!ok) {
@@ -435,7 +500,7 @@ static QString getCurrentGroupName()
 KArchiveDirectory *KArchive::rootDir()
 {
     if (!d->rootDir) {
-        //qCDebug(KArchiveLog) << "Making root dir ";
+        // qCDebug(KArchiveLog) << "Making root dir ";
         QString username = ::getCurrentUserName();
         QString groupname = ::getCurrentGroupName();
 
@@ -446,10 +511,23 @@ KArchiveDirectory *KArchive::rootDir()
 
 KArchiveDirectory *KArchive::findOrCreate(const QString &path)
 {
-    //qCDebug(KArchiveLog) << path;
+    return d->findOrCreate(path, 0 /*recursionCounter*/);
+}
+
+KArchiveDirectory *KArchivePrivate::findOrCreate(const QString &path, int recursionCounter)
+{
+    // Check we're not in a path that is ultra deep, this is most probably fine since PATH_MAX on Linux
+    // is defined as 4096, so even on /a/a/a/a/a/a 2500 recursions puts us over that limit
+    // an ultra deep recursion will makes us crash due to not enough stack. Tests show that 1MB stack
+    // (default on Linux seems to be 8MB) gives us up to around 4000 recursions
+    if (recursionCounter > 2500) {
+        qCWarning(KArchiveLog) << "path recursion limit exceeded, bailing out";
+        return nullptr;
+    }
+    // qCDebug(KArchiveLog) << path;
     if (path.isEmpty() || path == QLatin1String("/") || path == QLatin1String(".")) { // root dir => found
-        //qCDebug(KArchiveLog) << "returning rootdir";
-        return rootDir();
+        // qCDebug(KArchiveLog) << "returning rootdir";
+        return q->rootDir();
     }
     // Important note : for tar files containing absolute paths
     // (i.e. beginning with "/"), this means the leading "/" will
@@ -458,23 +536,24 @@ KArchiveDirectory *KArchive::findOrCreate(const QString &path)
     // See also KArchiveDirectory::entry().
 
     // Already created ? => found
-    const KArchiveEntry *ent = rootDir()->entry(path);
-    if (ent) {
-        if (ent->isDirectory())
-            //qCDebug(KArchiveLog) << "found it";
+    KArchiveDirectory *existingEntryParentDirectory;
+    const KArchiveEntry *existingEntry = KArchiveDirectoryPrivate::get(q->rootDir())->entry(path, &existingEntryParentDirectory);
+    if (existingEntry) {
+        if (existingEntry->isDirectory())
+        // qCDebug(KArchiveLog) << "found it";
         {
-            const KArchiveDirectory *dir = static_cast<const KArchiveDirectory *>(ent);
+            const KArchiveDirectory *dir = static_cast<const KArchiveDirectory *>(existingEntry);
             return const_cast<KArchiveDirectory *>(dir);
         } else {
-            const KArchiveFile *file = static_cast<const KArchiveFile *>(ent);
+            const KArchiveFile *file = static_cast<const KArchiveFile *>(existingEntry);
             if (file->size() > 0) {
                 qCWarning(KArchiveLog) << path << "is normal file, but there are file paths in the archive assuming it is a directory, bailing out";
                 return nullptr;
             }
 
             qCDebug(KArchiveLog) << path << " is an empty file, assuming it is actually a directory and replacing";
-            KArchiveEntry *myEntry = const_cast<KArchiveEntry*>(ent);
-            rootDir()->removeEntry(myEntry);
+            KArchiveEntry *myEntry = const_cast<KArchiveEntry *>(existingEntry);
+            existingEntryParentDirectory->removeEntry(myEntry);
             delete myEntry;
         }
     }
@@ -484,25 +563,26 @@ KArchiveDirectory *KArchive::findOrCreate(const QString &path)
     KArchiveDirectory *parent;
     QString dirname;
     if (pos == -1) { // no more slash => create in root dir
-        parent =  rootDir();
+        parent = q->rootDir();
         dirname = path;
     } else {
         QString left = path.left(pos);
         dirname = path.mid(pos + 1);
-        parent = findOrCreate(left);   // recursive call... until we find an existing dir.
+        parent = findOrCreate(left, recursionCounter + 1); // recursive call... until we find an existing dir.
     }
 
     if (!parent) {
         return nullptr;
     }
 
-    //qCDebug(KArchiveLog) << "found parent " << parent->name() << " adding " << dirname << " to ensure " << path;
+    // qCDebug(KArchiveLog) << "found parent " << parent->name() << " adding " << dirname << " to ensure " << path;
     // Found -> add the missing piece
-    KArchiveDirectory *e = new KArchiveDirectory(this, dirname, d->rootDir->permissions(),
-                                                 d->rootDir->date(), d->rootDir->user(),
-                                                 d->rootDir->group(), QString());
-    parent->addEntry(e);
-    return e; // now a directory to <path> exists
+    KArchiveDirectory *e = new KArchiveDirectory(q, dirname, rootDir->permissions(), rootDir->date(), rootDir->user(), rootDir->group(), QString());
+    if (parent->addEntryV2(e)) {
+        return e; // now a directory to <path> exists
+    } else {
+        return nullptr;
+    }
 }
 
 void KArchive::setDevice(QIODevice *dev)
@@ -516,7 +596,8 @@ void KArchive::setDevice(QIODevice *dev)
 
 void KArchive::setRootDir(KArchiveDirectory *rootDir)
 {
-    Q_ASSERT(!d->rootDir);   // Call setRootDir only once during parsing please ;)
+    Q_ASSERT(!d->rootDir); // Call setRootDir only once during parsing please ;)
+    delete d->rootDir; // but if it happens, don't leak
     d->rootDir = rootDir;
 }
 
@@ -556,7 +637,7 @@ QDateTime KArchivePrivate::time_tToDateTime(uint time_t)
     if (time_t == uint(-1)) {
         return QDateTime();
     }
-    return QDateTime::fromTime_t(time_t);
+    return QDateTime::fromSecsSinceEpoch(time_t);
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -566,8 +647,12 @@ QDateTime KArchivePrivate::time_tToDateTime(uint time_t)
 class KArchiveEntryPrivate
 {
 public:
-    KArchiveEntryPrivate(KArchive *_archive, const QString &_name, int _access,
-                         const QDateTime &_date, const QString &_user, const QString &_group,
+    KArchiveEntryPrivate(KArchive *_archive,
+                         const QString &_name,
+                         int _access,
+                         const QDateTime &_date,
+                         const QString &_user,
+                         const QString &_group,
                          const QString &_symlink)
         : name(_name)
         , date(_date)
@@ -587,9 +672,13 @@ public:
     KArchive *archive;
 };
 
-KArchiveEntry::KArchiveEntry(KArchive *t, const QString &name, int access, const QDateTime &date,
-                             const QString &user, const QString &group, const
-                             QString &symlink)
+KArchiveEntry::KArchiveEntry(KArchive *t,
+                             const QString &name,
+                             int access,
+                             const QDateTime &date,
+                             const QString &user,
+                             const QString &group,
+                             const QString &symlink)
     : d(new KArchiveEntryPrivate(t, name, access, date, user, group, symlink))
 {
 }
@@ -660,10 +749,15 @@ public:
     qint64 size;
 };
 
-KArchiveFile::KArchiveFile(KArchive *t, const QString &name, int access, const QDateTime &date,
-                           const QString &user, const QString &group,
+KArchiveFile::KArchiveFile(KArchive *t,
+                           const QString &name,
+                           int access,
+                           const QDateTime &date,
+                           const QString &user,
+                           const QString &group,
                            const QString &symlink,
-                           qint64 pos, qint64 size)
+                           qint64 pos,
+                           qint64 size)
     : KArchiveEntry(t, name, access, date, user, group, symlink)
     , d(new KArchiveFilePrivate(pos, size))
 {
@@ -693,7 +787,7 @@ QByteArray KArchiveFile::data() const
 {
     bool ok = archive()->device()->seek(d->pos);
     if (!ok) {
-        //qCWarning(KArchiveLog) << "Failed to sync to" << d->pos << "to read" << name();
+        // qCWarning(KArchiveLog) << "Failed to sync to" << d->pos << "to read" << name();
     }
 
     // Read content
@@ -715,27 +809,29 @@ bool KArchiveFile::isFile() const
     return true;
 }
 
-static QFileDevice::Permissions withExecutablePerms(
-    QFileDevice::Permissions filePerms,
-    mode_t perms)
+static QFileDevice::Permissions withExecutablePerms(QFileDevice::Permissions filePerms, mode_t perms)
 {
     if (perms & 01)
-      filePerms |= QFileDevice::ExeOther;
+        filePerms |= QFileDevice::ExeOther;
 
     if (perms & 010)
-      filePerms |= QFileDevice::ExeGroup;
+        filePerms |= QFileDevice::ExeGroup;
 
     if (perms & 0100)
-      filePerms |= QFileDevice::ExeOwner;
+        filePerms |= QFileDevice::ExeOwner;
 
     return filePerms;
 }
 
 bool KArchiveFile::copyTo(const QString &dest) const
 {
-    QFile f(dest + QLatin1Char('/')  + name());
+    QFile f(dest + QLatin1Char('/') + name());
     if (f.open(QIODevice::ReadWrite | QIODevice::Truncate)) {
         QIODevice *inputDev = createDevice();
+        if (!inputDev) {
+            f.remove();
+            return false;
+        }
 
         // Read and write data in chunks to minimize memory usage
         const qint64 chunkSize = 1024 * 1024;
@@ -764,22 +860,15 @@ bool KArchiveFile::copyTo(const QString &dest) const
 //////////////////////// KArchiveDirectory /////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
 
-class KArchiveDirectoryPrivate
-{
-public:
-    ~KArchiveDirectoryPrivate()
-    {
-        qDeleteAll(entries);
-    }
-    QHash<QString, KArchiveEntry *> entries;
-};
-
-KArchiveDirectory::KArchiveDirectory(KArchive *t, const QString &name, int access,
+KArchiveDirectory::KArchiveDirectory(KArchive *t,
+                                     const QString &name,
+                                     int access,
                                      const QDateTime &date,
-                                     const QString &user, const QString &group,
+                                     const QString &user,
+                                     const QString &group,
                                      const QString &symlink)
     : KArchiveEntry(t, name, access, date, user, group, symlink)
-    , d(new KArchiveDirectoryPrivate)
+    , d(new KArchiveDirectoryPrivate(this))
 {
 }
 
@@ -795,35 +884,8 @@ QStringList KArchiveDirectory::entries() const
 
 const KArchiveEntry *KArchiveDirectory::entry(const QString &_name) const
 {
-    QString name = QDir::cleanPath(_name);
-    int pos = name.indexOf(QLatin1Char('/'));
-    if (pos == 0) { // ouch absolute path (see also KArchive::findOrCreate)
-        if (name.length() > 1) {
-            name = name.mid(1);   // remove leading slash
-            pos = name.indexOf(QLatin1Char('/'));   // look again
-        } else { // "/"
-            return this;
-        }
-    }
-    // trailing slash ? -> remove
-    if (pos != -1 && pos == name.length() - 1) {
-        name = name.left(pos);
-        pos = name.indexOf(QLatin1Char('/'));   // look again
-    }
-    if (pos != -1) {
-        const QString left = name.left(pos);
-        const QString right = name.mid(pos + 1);
-
-        //qCDebug(KArchiveLog) << "left=" << left << "right=" << right;
-
-        const KArchiveEntry *e = d->entries.value(left);
-        if (!e || !e->isDirectory()) {
-            return nullptr;
-        }
-        return static_cast<const KArchiveDirectory *>(e)->entry(right);
-    }
-
-    return d->entries.value(name);
+    KArchiveDirectory *dummy;
+    return d->entry(_name, &dummy);
 }
 
 const KArchiveFile *KArchiveDirectory::file(const QString &name) const
@@ -836,14 +898,19 @@ const KArchiveFile *KArchiveDirectory::file(const QString &name) const
 }
 
 void KArchiveDirectory::addEntry(KArchiveEntry *entry)
+{
+    addEntryV2(entry);
+}
+
+bool KArchiveDirectory::addEntryV2(KArchiveEntry *entry)
 {
     if (d->entries.value(entry->name())) {
-        qCWarning(KArchiveLog) << "directory " << name()
-                    << "has entry" << entry->name() << "already";
+        qCWarning(KArchiveLog) << "directory " << name() << "has entry" << entry->name() << "already";
         delete entry;
-        return;
+        return false;
     }
     d->entries.insert(entry->name(), entry);
+    return true;
 }
 
 void KArchiveDirectory::removeEntry(KArchiveEntry *entry)
@@ -855,13 +922,11 @@ void KArchiveDirectory::removeEntry(KArchiveEntry *entry)
     QHash<QString, KArchiveEntry *>::Iterator it = d->entries.find(entry->name());
     // nothing removed?
     if (it == d->entries.end()) {
-        qCWarning(KArchiveLog) << "directory " << name()
-                   << "has no entry with name " << entry->name();
+        qCWarning(KArchiveLog) << "directory " << name() << "has no entry with name " << entry->name();
         return;
     }
     if (it.value() != entry) {
-        qCWarning(KArchiveLog) << "directory " << name()
-                   << "has another entry for name " << entry->name();
+        qCWarning(KArchiveLog) << "directory " << name() << "has another entry for name " << entry->name();
         return;
     }
     d->entries.erase(it);
@@ -889,8 +954,8 @@ bool KArchiveDirectory::copyTo(const QString &dest, bool recursiveCopy) const
     QStack<const KArchiveDirectory *> dirStack;
     QStack<QString> dirNameStack;
 
-    dirStack.push(this);       // init stack at current directory
-    dirNameStack.push(destDir);   // ... with given path
+    dirStack.push(this); // init stack at current directory
+    dirNameStack.push(destDir); // ... with given path
     do {
         const KArchiveDirectory *curDir = dirStack.pop();
 
@@ -898,9 +963,8 @@ bool KArchiveDirectory::copyTo(const QString &dest, bool recursiveCopy) const
         // otherwise put file under root position in extraction folder
         QString curDirName = dirNameStack.pop();
         if (!QDir(curDirName).absolutePath().startsWith(destDir)) {
-            qCWarning(KArchiveLog) << "Attempted export into folder" << curDirName
-                << "which is outside of the extraction root folder" << destDir << "."
-                << "Changing export of contained files to extraction root folder.";
+            qCWarning(KArchiveLog) << "Attempted export into folder" << curDirName << "which is outside of the extraction root folder" << destDir << "."
+                                   << "Changing export of contained files to extraction root folder.";
             curDirName = destDir;
         }
 
@@ -921,7 +985,7 @@ bool KArchiveDirectory::copyTo(const QString &dest, bool recursiveCopy) const
 #endif
                 QFile symLinkTarget(curEntry->symLinkTarget());
                 if (!symLinkTarget.link(linkName)) {
-                    //qCDebug(KArchiveLog) << "symlink(" << curEntry->symLinkTarget() << ',' << linkName << ") failed:" << strerror(errno);
+                    // qCDebug(KArchiveLog) << "symlink(" << curEntry->symLinkTarget() << ',' << linkName << ") failed:" << strerror(errno);
                 }
             } else {
                 if (curEntry->isFile()) {
@@ -943,10 +1007,9 @@ bool KArchiveDirectory::copyTo(const QString &dest, bool recursiveCopy) const
         }
     } while (!dirStack.isEmpty());
 
-    std::sort(fileList.begin(), fileList.end(), sortByPosition);    // sort on d->pos, so we have a linear access
+    std::sort(fileList.begin(), fileList.end(), sortByPosition); // sort on d->pos, so we have a linear access
 
-    for (QList<const KArchiveFile *>::const_iterator it = fileList.constBegin(), end = fileList.constEnd();
-         it != end; ++it) {
+    for (QList<const KArchiveFile *>::const_iterator it = fileList.constBegin(), end = fileList.constEnd(); it != end; ++it) {
         const KArchiveFile *f = *it;
         qint64 pos = f->position();
         if (!f->copyTo(fileToDir[pos])) {
